@@ -72,7 +72,6 @@ class Distribution(object):
             :class:`alnair.package.Package` or iterable of it
         :param *args: iterable of package name string or instance of
             :class:`alnair.package.Package`
-        :returns: True if install successful, otherwise False
         """
         args = list(args)
         if hasattr(pkgs, '__iter__'):
@@ -83,10 +82,9 @@ class Distribution(object):
         install_command = self.get_install_command(
                 kwargs.get('install_command'))
         pkgs = ' '.join(pkg.name for pkg in packages)
-        success = fa.sudo('%s %s' % (install_command, pkgs)).succeed
-        if success and not self._within_context:
+        fa.sudo('%s %s' % (install_command, pkgs))
+        if not self._within_context:
             self.after_install()
-        return success
 
     def after_install(self):
         for pkg in self._packages:
@@ -96,8 +94,9 @@ class Distribution(object):
                 fa.put(sio, filename, use_sudo=True)
                 for cmd in config._cmd._commands:
                     fa.sudo(cmd)
-        for cmd in self.get_after_commands(setup.after):
-            fa.sudo(cmd)
+        if setup.after:
+            for cmd in self.get_after_commands(setup.after):
+                fa.sudo(cmd)
 
     def get_after_commands(self, after):
         """Get an command of after an install
@@ -111,7 +110,8 @@ class Distribution(object):
             return self.get_after_commands(after())
         else:
             fa.abort(u"`after` type must be instance of"
-                     u" `alnair.command.Command` or callable")
+                     u" `alnair.command.Command` or callable, but %s" %
+                     type(after))
 
     def get_install_command(self, default_install_command=None):
         """Get an install command
@@ -153,7 +153,7 @@ class Distribution(object):
                 result.append(pkg)
             else:
                 fa.abort(u"provided package types must be Package instance or"
-                         u" string")
+                         u" string, but %s" % type(pkg))
         return result
 
     def get_package(self, pkg):
